summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmaddcommand.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commite7366c97c998679efa80cf61c88e64a11a3d3c33 (patch)
treea161d2940165f6cc47c05f0271ad8e5f64ffe6e8 /kpovmodeler/pmaddcommand.h
parentda4be7880ff1de6415ab6256afd2514e64f5fa2e (diff)
downloadtdegraphics-e7366c97c998679efa80cf61c88e64a11a3d3c33.tar.gz
tdegraphics-e7366c97c998679efa80cf61c88e64a11a3d3c33.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpovmodeler/pmaddcommand.h')
-rw-r--r--kpovmodeler/pmaddcommand.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kpovmodeler/pmaddcommand.h b/kpovmodeler/pmaddcommand.h
index a5759ea8..51beec31 100644
--- a/kpovmodeler/pmaddcommand.h
+++ b/kpovmodeler/pmaddcommand.h
@@ -38,22 +38,22 @@ public:
/**
* Command that adds a new PMObject.
*
* The object obj will be inserted as child of tqparent after
* the object after.
*
* If after is 0, the object becomes the first child.
*/
- PMAddCommand( PMObject* obj, PMObject* tqparent, PMObject* after );
+ PMAddCommand( PMObject* obj, PMObject* parent, PMObject* after );
/**
* Command that adds a list of new PMObjects.
*
* The object in the list will be inserted as tqchildren of tqparent after
* the object after.
*
* If after is 0, the objects will be inserted as first tqchildren.
*/
- PMAddCommand( const PMObjectList& list, PMObject* tqparent, PMObject* after );
+ PMAddCommand( const PMObjectList& list, PMObject* parent, PMObject* after );
/**
* Deletes the command. The inserted object will be deleted, if
the command was not executed (or undo-ed) */
@@ -38,22 +38,22 @@ public:
* Command that adds a new PMObject.
*
- * The object obj will be inserted as child of tqparent after
+ * The object obj will be inserted as child of parent after
* the object after.
*
@@ -38,22 +38,22 @@ public:
* Command that adds a list of new PMObjects.
*
- * The object in the list will be inserted as tqchildren of tqparent after
+ * The object in the list will be inserted as tqchildren of parent after
* the object after.
*